Changelog
---------

0.1.2 (2018-05-10)
~~~~~~~~~~~~~~~~~~~~~

- Increases the download speed during restore operations.
  [href]

- Shows a warning when a user/group could not be found during restore.
  [href]

- Lowers the timeouts and retry rates.
  [href]

0.1.1 (2018-05-04)
~~~~~~~~~~~~~~~~~~~~~

- Lowers the number of requests needed to upload data.
  [href]

0.1.0 (2018-04-26)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]
